searchData={"items":[{"type":"module","title":"Mpgs","doc":"This module deals with the MasterCard Payment Gateway Service (MPGS).\n\nCheck the MPGS API documentation for more details:\n\nhttps://ap-gateway.mastercard.com/api/documentation/apiDocumentation/rest-json/version/latest/api.html?locale=en_US","ref":"Mpgs.html"},{"type":"function","title":"Mpgs.authenticate_payment/1","doc":"Use this function to start the payment process.\n\nThe value of the function is a piece of HTML that should be rendered on the client's browser.\n\nThis funciton takes a map and returns a tuple.\n\nAvailable map keys:\n- `api_username`. Required. Optional if there is an env variable called `MPGS_API_USERNAME`.\n- `api_password`. Required. Optional if there is an env variable called `MPGS_API_PASSWORD`.\n- `api_base`. Optional. Defaults to https://ap-gateway.mastercard.com/api/rest/version.\n- `api_version`. Optional. Defaults to 74.\n- `api_merchant`. Required.\n- `session`. Optional. A new session will be created if this key does not exist.\n- `currency`. Optional. The 3-digit currency code. Defaults to KWD.\n- `amount`. Required. It must be a number that indicates the total amount to be paid.\n- `card_number`. Required. The 16-digit card number used for the payment. Optional if the session is provided and it already contains the card data.\n- `expiry_month`. Required. The card's 2-digit expiry month.  Optional if the session is provided and it already contains the card data.\n- `expiry_year`. Required. The card's 2-digit expiry year.  Optional if the session is provided and it already contains the card data.\n- `security_code`. Required. The card's 3-digit (or 4-digit) CVV code.  Optional if the session is provided and it already contains the card data.\n- `order`. Required. The order number.\n- `trx`. Required. The transaction number.\n- `response_url`. Required. The URL that will receive the authentication response from the MPGS gateway.\n- `browser_agent`. Required. The user's browser agent string.\n- `full_page_redirect`. Optional. If `true`, this function will return a complete html document which can be rendered as a full page.\n\nIf you are not PCI compliant, you should provide a session which already contains card details.\n\nThis session is obtained by the MPGS gateway through the [Hosted Session Integration](https://ap-gateway.mastercard.com/api/documentation/integrationGuidelines/hostedSession/integrationModelHostedSession.html) guide:\n\nReturn values:\n- `{:ok, session, html}`. The `html` value should be rendered on the client's web browser. The `session` should be used with the `capture_payment/1` function.\n- `{:error, exception}`. An error occurred while processing the authentication request.\n\nExample:\n\n```\nparams = %{\n  api_username: \"my-mpgs-username\",\n  api_password: \"my-mpgs-password\",\n  api_merchant: \"my-mpgs-merchant\",\n  amount: \"15\",\n  currency: \"KWD\",\n\n  # include a session which contains card details:\n  session: \"SESSION2483924783297489234\",\n  # or include card details:\n  card_number: \"1234567890123456\",\n  expiry_month: \"10\",\n  expiry_year: \"25\",\n  security_code: \"123\",\n\n  order: \"0123456789\",\n  trx: \"0987654321\",\n  response_url: \"http://example.com/payment/mpgs/response/\",\n  browser_agent: \"Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7)...Version/16.5.2 Safari/605.1.15\",\n  full_page_redirect: true,\n}\n\n{:ok, session, html} = authenticate_payment(params)\n# Send and render the html on client's browser.\n# After a successful or a failed authentication attempt by the user,\n# call the capture_payment/1 function.\nparams = Map.put(params, :session, session)\n{:ok, result} = capture_payment(params)\n```","ref":"Mpgs.html#authenticate_payment/1"},{"type":"function","title":"Mpgs.capture_payment/2","doc":"Use this function to capture (charge) the card.\n\nThis function must be used after the `authenticate_payment/1` function.\n\nAvailable map keys:\n- `session`. Required. This is obtained from calling `authenticate_payment/1` first.\n- `currency`. Optional. Defaults to `KWD`.\n- `amount`. Required. The same amount used with the `authenticate_payment/1` function.\n- `order`. Required. The same order number used with the `authenticate_payment/1` function.\n- `trx`. Required. The same transaction number used with the `authenticate_payment/1` function.\n- `api_username`. Required. Optional if there is an env variable called `MPGS_API_USERNAME`.\n- `api_password`. Required. Optional if there is an env variable called `MPGS_API_PASSWORD`.\n- `api_base`. Optional. Defaults to https://ap-gateway.mastercard.com/api/rest/version.\n- `api_version`. Optional. Defaults to 74.\n- `api_merchant`. Required.","ref":"Mpgs.html#capture_payment/2"},{"type":"function","title":"Mpgs.check_connectivity/1","doc":"Returns `true` if the MPGS API is operational, `false` otherwise.\n\nAvailable map keys:\n- `api_base`. Optional. Defaults to https://ap-gateway.mastercard.com/api/rest/version.\n- `api_version`. Optional. Defaults to 74.\n\n```\nMpgs.check_connectivity()\ntrue\n```","ref":"Mpgs.html#check_connectivity/1"},{"type":"function","title":"Mpgs.refund_transaction/1","doc":"Use this function to refund a paid transaction.\n\nAvailable map keys:\n- `order`. Required. The order number used with the `capture_payment/1` function.\n- `trx`. Required. The transaction number used with the `capture_payment/1` function.\n- `amount`. Required.\n- `api_username`. Required. Optional if there is an env variable called `MPGS_API_USERNAME`.\n- `api_password`. Required. Optional if there is an env variable called `MPGS_API_PASSWORD`.\n- `api_base`. Optional. Defaults to https://ap-gateway.mastercard.com/api/rest/version.\n- `api_version`. Optional. Defaults to 74.\n- `api_merchant`. Required.\n\nExample:\n```\norder_params = %{\n  api_username: \"my-mpgs-username\",\n  api_password: \"my-mpgs-password\",\n  api_merchant: \"my-mpgs-merchant\",\n  order: \"0123456789\",\n  trx: \"0987654321\",\n  amount: \"15\",\n  currency: \"KWD\"\n}\n\n{:ok, response} = Mpgs.refund_transaction(params)\nresponse[\"result\"] #=> \"SUCCESS\"\nresponse[\"order\"][\"status\"] #=> \"REFUNDED\"\n```","ref":"Mpgs.html#refund_transaction/1"},{"type":"function","title":"Mpgs.retrieve_transaction/1","doc":"Retrieves details about an existing transaction.\n\nAvailable map keys:\n- `order`. Required. The same order number used with the `capture_payment/1` function.\n- `trx`. Required. The same transaction number used with the `capture_payment/1` function.\n- `api_username`. Required. Optional if there is an env variable called `MPGS_API_USERNAME`.\n- `api_password`. Required. Optional if there is an env variable called `MPGS_API_PASSWORD`.\n- `api_base`. Optional. Defaults to https://ap-gateway.mastercard.com/api/rest/version.\n- `api_version`. Optional. Defaults to 74.\n- `api_merchant`. Required.","ref":"Mpgs.html#retrieve_transaction/1"}],"content_type":"text/markdown"}